import QtQuick 1.1
import "../fonts" as Fonts
import "../Colors.js" as Colors
import "../Common.js" as Common
import "../Stat.js" as Stat

Item
{
    id: hyperlink
	property string text
	property bool underline: true
    property alias color: text.color
	signal clicked
	property int tabOrder: 1
	property bool setFocusOnPressed: tabOrder ? true : false
	property variant standartFontStyles: Fonts.Common{}
	property alias horizontalAlignment: text.horizontalAlignment
	property alias font: text.font
    property alias elide: text.elide
    property bool hovered: mouseArea.containsMouse
	width: text.paintedWidth
	height: text.paintedHeight

    HotKeyParser
    {
        id: hotKeyParser
        text: hyperlink.text
    }
    HotKey
    {
        text: hotKeyParser.hotKeyText
        onPressed: hyperlink.clicked()
    }

	Text
	{
		id: text
        text: hotKeyParser.textToShow
        color: enabled ? Colors.hyperlinkColor : "gray"
		font: standartFontStyles.standardCommonTextFont

        FocusImage
        {
            target: hyperlink
            anchors.left: parent.left
            anchors.leftMargin: -4
            anchors.verticalCenter: parent.verticalCenter
            widthClipperSize: -6
            tileHorizontally: true
            border {
                left: 4
                right: 4
            }
            source: "../images/focuses/focus_gray_rect.png"
        }
	}
	Keys.onSpacePressed: hyperlink.clicked()

	Binding
	{
		target: text
		property: "font.underline"
		value: hyperlink.underline
	}

	MouseArea
    {
        id: mouseArea
		anchors.fill: text
		hoverEnabled: true
		Clickable {}
		onPressed:
		{
			if (!hyperlink.activeFocus && hyperlink.setFocusOnPressed)
				hyperlink.forceActiveFocus();
		}
		onClicked:
		{
            Stat.onButtonClick(Common.buildDelegatelessPath(hyperlink));
			hyperlink.clicked()
		}
	}
}
