import QtQuick 1.1
import QtWidgetProxies 1.0
import "../fonts" as Fonts
import "../EnumHelper.js" as EnumHelper
import "../ProductTypeHelper.js" as ProductTypeHelper

SecondaryWindow
{
	Localizer { id:tr; scope: MessageBoxData.scope } 
	property variant commonFontStyles: Fonts.Common{}
	property variant context: MessageBoxContext

	function getSeverityIcon()
	{
		return EnumHelper.convert(MessageBoxData, "Severity", {
			"Info":"../images/ico_info_48.png",
			"Warning":"../images/ico_warning_48.png",
			"Critical":"../images/ico_danger_48.png"});
	}

	SystemPalette {id: activePalette}

	id: notification
	objectName:	"MessageBox"
	caption: tr.scope != "" ? (MessageBoxData.Caption != "" ? tr.Localize(MessageBoxData.Caption) : ProductTypeHelper.getProductNameFull(tr, context)) : "";
	hasFooter: false
	width: 500
	height: workAreaItem.childrenRect.height + 78
    property int standardButtonWidth: 70

	workArea : Item
	{
		id: workArea
		objectName:	"workArea"

		Image
		{
			id: icon
			source: getSeverityIcon()
			anchors.left: parent.left;
			anchors.leftMargin: 20
			anchors.top: parent.top;
			anchors.topMargin: 20
		}

		Text
		{
			id: title
			anchors.left: icon.right;
			anchors.leftMargin: 20;
			anchors.top: icon.top;
			anchors.right: parent.right;
			anchors.rightMargin: 20;
			text: tr.Localize(MessageBoxData.Description)
			wrapMode: Text.WordWrap
			font.family: "Tahoma"
			font.pointSize: 10
			font.bold: true
			horizontalAlignment: Text.AlignLeft
		}

		Text
		{
			id: description
			anchors.left: title.left;
			anchors.top: title.bottom;
			anchors.topMargin: 5
			anchors.right: parent.right;
			anchors.rightMargin: 20;
			text: tr.Localize(MessageBoxData.AdditionalDescription)
			wrapMode: Text.WordWrap
			horizontalAlignment: Text.AlignLeft
			font.family: "Tahoma"
			font.pointSize: 9
		}

		Column // links group
		{
			id: linksGroup

			anchors
			{
				left: description.left;
				top: description.bottom;
				topMargin: 5
				right: parent.right;
				rightMargin: 20;
			}

			width: childrenRect.width
			spacing: 5
			objectName:	"linksGroup"

			Repeater
			{
				id: linksGroupRepeater
				objectName:	"linksGroupRepeater"
				model: MessageBoxData.ExtraItems

				Hyperlink
				{
					objectName:	"MessageBoxGeneratedLink"
					text: tr.Localize(model.modelData.Text)
					onClicked: Window.CloseWithResult(model.modelData.Id);
				}
			}
		}

		Row // buttons group
		{
			anchors
			{
				right: parent.right
				rightMargin: 20
				top: linksGroup.bottom
				topMargin: 20
			}

			spacing: 5
			objectName:	"buttonsGroup"

			Repeater
			{
				id: buttonsGroupRepeater
				objectName:	"buttonsGroupRepeater"
				model: MessageBoxData.Buttons

				GrayButton
				{
					objectName:	"MessageBoxGeneratedButton"
					text: tr.Localize(model.modelData.Text)
					onClicked: Window.CloseWithResult(model.modelData.Id);
                    minWidth: notification.standardButtonWidth
				}
			}
		}
	}
}
