import QtQuick 1.1
import "../fonts" as Fonts
import "../EnumHelper.js" as EnumHelper
import "../Colors.js" as Colors

PageFrame
{
    id: wizard
    objectName: "wizard"
	property variant localizer
    property variant context
    property variant fontStyles: Fonts.Common{}
    property variant currentPage

    property alias workAreaLeftGap: workingArea.leftGap

    property alias headerText: headerText.text

	signal showHelp

    backButtonVisible: true
    backButtonEnabled: pagesStack.count && (currentPage ? currentPage.backButtonEnabled : false);
    backButtonText: (currentPage && currentPage.backButtonText) ? currentPage.backButtonText : localizer.Localize("BackButton")

    nextButtonVisible: true
    nextButtonEnabled: currentPage ? currentPage.nextButtonEnabled : false;
    nextButtonText: (currentPage && currentPage.nextButtonText) ? currentPage.nextButtonText : localizer.Localize("NextButton")

    cancelButtonVisible: true
    cancelButtonEnabled: currentPage ? currentPage.cancelButtonEnabled : false
    cancelButtonText: (currentPage && currentPage.cancelButtonText) ? currentPage.cancelButtonText : localizer.Localize("Cancel")

    helpButtonVisible: currentPage ? currentPage.helpButtonVisible : true

	function getHelpId()
	{
		if (currentPage && (typeof currentPage.getHelpId == 'function'))
			return currentPage.getHelpId();
		return 0;
	}

    Connections {onHelp: if (currentPage) wizard.showHelp();}
    Connections {onClose: if (currentPage) currentPage.onClose();}
    Connections {onBack: if (currentPage) currentPage.onBack();}
    Connections {onNext: if (currentPage) currentPage.onNext();}
    Connections {onCancel: if (currentPage) currentPage.onCancel();}

    ListModel{id: pagesStack}

    function selectPageOnStateChanged(saveCurrentPage)
    {
        // override it in derived
    }

    function setNewPage(page, saveCurrentPage)
    {
        if (page == currentPage)
                return;

        if (currentPage != undefined)
        {
            currentPage.visible = false;
            if (saveCurrentPage)
                pagesStack.append({"page": currentPage});
        }
        currentPage = page;
        currentPage.visible = true;
    }

    function backToPreviousPage()
    {
        if (!pagesStack.count)
                return;
        if (currentPage != undefined)
            currentPage.visible = false;
        currentPage = pagesStack.get(pagesStack.count - 1).page;
        pagesStack.remove(pagesStack.count - 1);
        currentPage.visible = true;
    }

    function getWorkingArea()
    {
        return pagesWorkingArea;
    }

    Item
    {
        id: workingArea
        objectName: "workingArea"

        property int topGap:	29
        property int bottomGap:	43
        property int leftGap:	164 /* banner width */  + 10 /*left border*/
        property int rightGap:	10

		anchors.left:	parent.left; anchors.leftMargin: leftGap
        y: topGap
        width: parent.width - leftGap - rightGap
        height: parent.height - topGap - bottomGap

        Column
		{
			id:	header
			clip: true
            width: parent.width
			anchors.left: parent.left;
			anchors.top: workingArea.top

			Item { width: parent.width; height: 30 }
			StandardCaptionText
			{
				id: headerText

                property int marginWidth: 30
				anchors.left:	parent.left; anchors.leftMargin: marginWidth
				anchors.right:	parent.right; anchors.rightMargin: marginWidth
				text:	wizard.currentPage ? wizard.currentPage.headerString : ""
				wrapMode: Text.Wrap
			}
			Item { width: parent.width; height: 20 }
		}

        Rectangle
        {
            id: workingAreaSplitter
            width: parent.width
			anchors.left: parent.left;
            anchors.top: header.bottom
            height: 1
            color: Colors.grayBorder
        }

        Item
        {
            objectName: "padding"
            width: parent.width
			anchors.left: parent.left;
            anchors.top: workingAreaSplitter.bottom
            anchors.bottom: workingArea.bottom
            clip: true

            Item
            {
                objectName: "pagesWorkingArea"
                id: pagesWorkingArea
                property int marginWidth: 30
                anchors.fill: parent
                anchors.margins: marginWidth
            }
        }
    }
}
