import QtQuick 1.1
import ".." as Widgets
import "../../Common.js" as Common
import "../../Stat.js" as Stat

Item
{
	id: widget

	property variant target
	property string property
	property int minValue
    property int maxValue

	property int targetValue: target[property]

	property int tabOrder: 1

	height: Math.max(lineLoader.height, slider.height)
	width: parent.width

	Component
	{
		id: defaultLine
		Item
		{
			id: lineItem
            height: 23;
            BorderImage
			{
                id: trackbar
                source: enabled ? "../../images/widgets/trackbar_normal.png" : "../../images/widgets/trackbar_disabled.png"
				anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 1
                width: parent.width - 2
                border {left: 4; right: 4; top: 0; bottom: 0}
			}
		}
	}

	Component
	{
		id: defaultSlider
		Item
		{
            width: slider.width
            height: 23

            function getImage()
            {
                if (enabled)
                {
                    if ((lineLoaderMouseArea.containsMouse || lineLoaderMouseArea.pressedButtons == Qt.LeftButton) ||
                            (sliderMouseArea.containsMouse || sliderMouseArea.pressedButtons == Qt.LeftButton))
                        return "../../images/widgets/slider_pressed.png"
                    else
                        return "../../images/widgets/slider_normal.png"
                }
                else
                {
                    return "../../images/widgets/slider_disabled.png"
                }
            }

            Image
			{
                id: slider
                source: getImage()
				anchors.left: parent.left
				anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
			}
		}
	}

	Component.onCompleted: syncSliderToValue()

	Loader
	{
		id: lineLoader
		sourceComponent: defaultLine
		anchors.verticalCenter:  parent.verticalCenter
        width: parent.width
		onWidthChanged: syncSliderToValue()
	}

	MouseArea
	{
		id: lineLoaderMouseArea
		anchors.horizontalCenter: lineLoader.horizontalCenter
        width: lineLoader.width
		anchors.top: lineLoader.top
		anchors.bottom: lineLoader.bottom
		hoverEnabled: true
		Widgets.Clickable {}
		onPressed: widget.forceActiveFocus()
		onClicked:
        {
			var newValue = Math.round((widget.minValue + (widget.maxValue - widget.minValue) * mouse.x / lineLoaderMouseArea.width))
			if (newValue != targetValue)
			{
				widget.setNewTargetValue(newValue)
			}
			else
			{
				var shift = mouse.x - slider.x
				if (shift > 0)
					incrementTargetValue()
				else if (shift < 0)
					decrementTargetValue();
			}
		}
	}

	onTargetValueChanged:
	{
		syncSliderToValue();
	}

	function syncSliderToValue()
	{
		if (sliderMouseArea.drag.active)
			return;
		slider.x = getShiftForCurrentValue();
	}

	function getShiftForCurrentValue()
	{
		return getShiftForValue(targetValue);
	}

	function getShiftForValue(value)
	{
		var shift = (lineLoader.width - slider.width) * (value - minValue) / (maxValue - minValue);
		return shift;

	}

	function getXForValue(value)
	{
		return slider.width / 2 + getShiftForValue(value);
	}

	Loader
	{
		id: slider
		sourceComponent: defaultSlider
		anchors.verticalCenter: parent.verticalCenter
		onXChanged:
		{
			var newValue = (widget.maxValue - widget.minValue) * slider.x / (lineLoader.width - slider.width) + widget.minValue;
			setNewTargetValue(newValue)
		}
	}
	MouseArea
	{
		id: sliderMouseArea
        anchors.fill: slider
		hoverEnabled: true
		drag
		{
			target: slider
			axis: Drag.XAxis
            minimumX: 0
            maximumX: lineLoader.width - slider.width
			onActiveChanged:
			{
				if (!drag.active)
					syncSliderToValue()
			}
		}
		Widgets.Clickable {}
	}

	function decrementTargetValue()
	{
		if (targetValue === minValue)
			return;
		setNewTargetValue(targetValue - 1);
	}
	function incrementTargetValue()
	{
		if (targetValue === maxValue)
			return;
		setNewTargetValue(targetValue + 1);
	}
	function sendStatisticsOnValueChanged(value)
	{
		var path = Common.buildDelegatelessPath(widget) + ".SliderValue.";
		var key = EnumExtension.GetKeyByIndex(target, property, value);
		if (key)
			path += key;
		else
			path += "Pos" + value;
        Stat.onButtonClick(path);
	}
	function setNewTargetValue(newValue)
	{
		var value = Math.round(newValue);
		if (value != target[property])
		{
			target[property] = value;
			sendStatisticsOnValueChanged(value);
		}
	}
}
