import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/HelpMapper.js" as HelpMapper

InnerContent
{
	Localizer { id:tr; scope:"MainWindow" }
	caption: tr.Localize("AdvancedTools")
    property int helpId: HelpMapper.MainWindowAdvancedToolsHelpId
	objectName: "advancedTools"

	viewArea: Component
	{
		
        FocusScope
        {
	        property int tabOrder: 1 

			property variant context: MainWindow
			objectName: "viewArea"
			anchors.fill: parent

			Widgets.KeyNavigation
			{
				id: keyNavigations

				Component.onCompleted:
				{
					var items = [
						rescueDiskTool, 
						systemRestoreTool,
						cleanerTool,
						ieTweakFlipPanel];
					focusedItems = items;
				}
			}
			Keys.onUpPressed: keyNavigations.onSetPrevious(event)
			Keys.onDownPressed: keyNavigations.onSetNext(event)


			Column
			{
				width: parent.width
				height: parent.height
				objectName: "column"

				AdvancedTool
				{
					objectName: "RescueDiskTool"
					id: rescueDiskTool
					iconSource: "../common/images/advanced_tools/ico_rescue_disk_48.png"
					titleText: tr.Localize("RescueDiskAction")
					descriptionText: tr.Localize("RescueDiskInfo")
					actionButtonText: tr.Localize("Launch")
					action: context.MakeRescueDiskAction
					hasSeparator: false
                    focus: true
				}
				
				AdvancedTool
				{
					objectName: "SystemRestoreTool"
					id: systemRestoreTool
					iconSource: "../common/images/advanced_tools/ico_infection_recovery_48.png"
					titleText: tr.Localize("SystemRestoreAction")
					descriptionText: tr.Localize("SystemRestoreInfo")
					actionButtonText: tr.Localize("Execute")
					action: context.SystemRestoreAction
				}				

				AdvancedTool
				{
					objectName: "CleanerTool"
					id: cleanerTool
					iconSource: "../common/images/advanced_tools/ico_activity_clean_48.png"
					titleText: tr.Localize("CleanerAction")
					descriptionText: tr.Localize("CleanerInfo")
                    actionButtonText: tr.Localize("CleanerExecute")
					action: context.CleanInfectionAction
				}

				AdvancedTool
				{
					objectName: "IeTweakFlipPanel"
					id: ieTweakFlipPanel
					iconSource: "../common/images/advanced_tools/ico_browser_configure_wizard_48.png"
					titleText: tr.Localize("IeTweakAction")
					descriptionText: tr.Localize("IeTweakInfo")
                    actionButtonText: tr.Localize("BrowserExecute")
					action: context.IeTweakAction
				}
			}
		}
	}
}
