import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../main_window" as MainFrame
import "../common/DateTime.js" as DateTime
import "../common/HelpMapper.js" as HelpMapper

MainFrame.InnerContent
{
    id: newsList

	Localizer { id:tr; scope:"NewsList" }
	caption: tr.Localize("NewsList_Title")
    property int helpId: HelpMapper.NewsListHelpId
	objectName: "newsList"

	Component.onCompleted:
	{
		MainWindow.newsList.SetNewsListVisited(); 
	}
	onVisibleChanged:
	{
		MainWindow.newsList.SetNewsListVisited(); 
	}
    captionArea: Component
    {
        Item
        {
            property variant context: MainWindow.newsList
            objectName: "captionArea"

            Widgets.CaptionButton
            {
                id: settingsButton
                objectName: "settingsButton"
                minWidth: 0
                iconImage: "../images/news/ico_bell.png";
				mirror: Window.Mirror
                onClicked: { 
                    MainWindow.InvokeSkinAction("dialog(\"NewsSettings\")")
                }
            }
        }
    }

    viewArea: Component
    {
        Item
        {
            property variant context: MainWindow.newsList
            property variant commonFontStyles: Fonts.Common{}
            objectName: "listFrameOuter"

            Item
            {
                anchors.fill: parent
                clip: true
                objectName: "listFrameInner"

                Widgets.ScrollBar
                {
                    id: scrollbar
                    target: newsListView
                    height: parent.height
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.right: parent.right
                }

                ListView
                {
                    id: newsListView
                    objectName: "newsListView"

                    anchors
                    {
                        left: parent.left
                        top: parent.top
                        bottom: parent.bottom
                        right: scrollbar.left
                    }

                    model: context.news
                    clip: true
                    delegate:
                    Item
                    {
                        id: row
                        objectName: "row"
                        width: parent.width
                        height: childrenRect.height + title.anchors.topMargin

                        Text
                        {
                            id: title
                            anchors.left: parent.left
                            anchors.leftMargin: 30
                            anchors.top: parent.top
                            anchors.topMargin: 23
                            font: commonFontStyles.standardSmallCaptionFont
                            text: model.modelData.title
                            color: EnumHelper.convert(model.modelData, "read",
                                                      {"Read":"#7f007e",
                                                          "Unread":"#1b786a"});
                            wrapMode: Text.Wrap
                            horizontalAlignment: Text.AlignLeft
                        }

                        Rectangle
                        {
                            height: 1
                            anchors.left: title.left
                            anchors.right: title.right
                            anchors.top: title.bottom
                            anchors.topMargin: -3
                            color: title.color
                        }

                        Item
                        {
                            id: subTitle
                            height: childrenRect.height
                            anchors.top: title.bottom
                            anchors.topMargin: 7
                            anchors.left: title.left;

                            Text
                            {
                                id: dateTime

                                color: "#7f7f7f"
                                text: DateTime.localizeDateTimeForNews(model.modelData.dateTime, tr, " ");
                                font: commonFontStyles.standardCommonTextFont
                            }

                            Text
                            {
                                id: subTitleSeparator
                                text: "|"
                                font: dateTime.font
                                color: dateTime.color

                                anchors.left: dateTime.right
                                anchors.leftMargin: 5
                                anchors.verticalCenter: dateTime.verticalCenter
                                visible: EnumHelper.convert(model.modelData, "importance",
                                                            {"Alert":true,
                                                             "Warning":true,
                                                             "Information":false});
                            }

                            BorderImage
                            {
                                id: statusIcon
                                anchors.left: subTitleSeparator.right
                                anchors.leftMargin: 7
                                anchors.verticalCenter: subTitleSeparator.verticalCenter
                                anchors.verticalCenterOffset: 1
                                height: 20
                                width: childrenRect.width + 30 - (childrenRect.width + 30) % 3

                                horizontalTileMode: BorderImage.Repeat
                                border {
                                    top: 5
                                    bottom: 4
                                    left: 9
                                    right: 12
                                }

                                source: EnumHelper.convert(model.modelData, "importance",
                                            {"Alert":"../common/images/news/news_alert.png",
                                             "Warning":"../common/images/news/news_alert.png",
                                             "Information":""});
                                Text
                                {
                                    anchors.centerIn: parent
                                    anchors.verticalCenterOffset: -1
                                    wrapMode: Text.Wrap
                                    color: "white"
                                    font: commonFontStyles.standardCommonTextFont
                                    text:
                                    {
                                        return EnumHelper.convert(model.modelData, "importance",
                                            {"Alert":tr.Localize("Alert"),
                                             "Warning":tr.Localize("Warning"),
                                             "Information":""});
                                    }
                                }
                            }
                        }

                        Text
                        {
                            id: description
                            anchors.left: title.left
                            anchors.right: parent.right
                            anchors.top: subTitle.bottom
                            anchors.topMargin: 6
                            height: text == "" ? 0 : paintedHeight
                            wrapMode: Text.WordWrap
							horizontalAlignment: Text.AlignLeft
                            font: commonFontStyles.standardCommonTextFont
                            text: model.modelData.description
                            clip: true
                        }

                        Widgets.GrayButton
                        {
                            id: readMore
                            objectName: "readMore"
                            anchors.left: title.left
                            anchors.top: description.bottom
                            anchors.topMargin: 16
                            text: tr.Localize("ReadMore")
                            onClicked:
                            {
                                context.currentNewsIndex = index;
								context.MarkCurrentArticleAsRead();
                                newsList.activate("panelNewsItem");
                            }
                        }

                        Rectangle
                        {
                            id: separator
                            anchors.top: readMore.bottom
                            anchors.topMargin: 27
                            width: parent.width
                            height: 1
                            color: "#e7e7e7"
                        }
                    }
                }
            }
        }
    }
}
