import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
	id: settingsPage
	objectName: "AntiSpam"

    property int helpId: HelpMapper.AntiSpamSettingsHelpId

	property variant context: SettingsHelper.GetPageContext(Settings, "AntiSpam")
	property variant fontStyles: Fonts.Common{}
	Localizer { id: tr; scope: "AntiSpamSettings" }
	Column
	{
        objectName: "MainWrapper"
		width: parent.width
		spacing: Margins.settingsPageSpacing
		SettingsCommon.SettingsSection
        {
            objectName: "AntiSpamGeneralSection"
            body: Column
            {
                width: parent.width
                objectName: "AntiSpamGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    anchors.left: parent.left
                    objectName: "EnableAntiSpam"
                    text: tr.Localize("UseAntispam");
                    isBold: true
                    target: context
                    property: "enableAntiSpam"
                }
            }
        }

		SettingsCommon.SecurityLevelSection
		{
            objectName: "SecurityLevel"
			context: settingsPage.context.levelViewModel
			enabled: settingsPage.context.enableAntiSpam
		}

        SettingsCommon.SettingsSection
        {
            objectName: "Training"
            visible: context.bayesEnabled
            name: tr.Localize("TrainingSection")
            smallBottomMargin: true

            body: Column
            {
                objectName: "Column"
                width: parent.width
                spacing: Margins.settingsSectionInnerSpacing
                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    text: tr.Localize("TrainingDescription")
                    wrapMode: Text.Wrap
                }

                Column
                {
                    objectName: "StartTrainingWrapper"
                    width: parent.width
                    spacing: Margins.settingsAfterTextSpacing

                    Row
                    {
                        SettingsCommon.SettingsStandardText
                        {
                            text: tr.Localize("Databases")
                        }

                        SettingsCommon.SettingsStandardText
                        {
                            text: tr.Localize(context.needTraining ? "NeedTrain" : "Filled")
                            isBold: true
                        }
                    }

                    SettingsCommon.SettingsButton
                    {
                        objectName: "StartTraining"
                        text: tr.Localize("Start")
                        onClicked: context.showTrainWizard()
                    }
                }
            }
        }
	}
}
