import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import ".." as SettingsCommon
import "../../common/fonts" as Fonts
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "Firewall"

    property string helpUrl: "$HelpURLSettingsFirewall"
    property int helpId: HelpMapper.FirewallSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "Firewall")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "FirewallSettings" }

    Column
    {
        objectName: "Column"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            body: Column
            {
                objectName: "FirewallSection"
                width:parent.width
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    id: firewallOn
                    objectName: "UseFirewall"
                    anchors.left: parent.left

                    text: tr.Localize("UseFirewall");
                    target: context
                    isBold: true
                    property: "enableFirewall"
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "NetworkRulesSection"
            name: tr.Localize("NetworkRulesSection")
            enabled: context.enableFirewall
            smallBottomMargin: true

            body: Column
            {
                objectName: "Column"
                spacing: 10
                width: parent.width

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    color: parent.enabled ? "black" : "grey"
                    text: tr.Localize("NetworkRulesDescription")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.SettingsButton
                {
                    objectName: "Settings"
                    text: tr.Localize("SettingsMore")
                    onClicked: context.OpenSettings()
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            id: networksLine
            objectName: "NetworksSection"
            name: tr.Localize("NetworksSection")
            anchors.left: parent.left
            smallBottomMargin: true

            body:FocusScope
            {
                id: scope

                objectName: "FocusRect"
                width: parent.width
				height: settingsPage.height - networksLine.y - 40

                Rectangle
                {
                    id: listRect
                    objectName: "ListRect"
                    width: parent.width
                    height: parent.height

                    enabled: context.enableFirewall

                    border
                    {
                        width: 1
                        color: "lightgray"
                    }

                    function getCurrentTextColor(itemId)
                    {
                        if (listRect.enabled)
                        {
                            if (list.current == itemId)
                                return scope.focus ? "white" : "black";
                            else
                                return "black";
                        }
                        else
                        {
                            return "gray";
                        }
                    }

                    function getCurrentSelectColor()
                    {
                        return listRect.enabled && scope.focus ? "#0d3256" : "#adcbff";
                    }

                    Column
                    {
                        y: 1
                        objectName: "Column"
                        anchors.left: parent.left
                        anchors.leftMargin: 1
                        width: parent.width - 1

                        Item
                        {
                            objectName: "Toolbar"
                            width: parent.width
                            height: toolImage.height

                            BorderImage
                            {
                                id: toolImage

                                source: "../../common/images/settings/firewall/toolbar.png"

                                visible: listRect.enabled

                                anchors.left: parent.left
                                anchors.right: parent.right

                                Widgets.DPIScaler {changeHeight: true}
                            }

                            Row
                            {
                                id: toolButtons
                                anchors.left: parent.left
                                anchors.leftMargin: 1
                                anchors.verticalCenter: parent.verticalCenter
                                objectName: "Row"
                                height: editButton.height + 4
                                width: parent.width - 1
                                spacing: 2

                                SettingsCommon.SettingsToolbarButton
                                {
                                    id: editButton

                                    iconImage: "../../common/images/settings/firewall/edit" + (enabled ? "" : "_disabled") + ".png"
                                    anchors.verticalCenter: parent.verticalCenter
                                    objectName: "Edit"
                                    text: tr.Localize("Edit")
                                    enabled: listRect.enabled && !!list.current && list.current.canEdit
                                    onClicked: list.current ? list.current.edit() : null
                                }

                                SettingsCommon.SettingsToolbarButton
                                {
                                    iconImage: "../../common/images/settings/firewall/delete" + (enabled ? "" : "_disabled") + ".png"
                                    anchors.verticalCenter: parent.verticalCenter
                                    objectName: "Delete"
                                    text: tr.Localize("Delete")
                                    enabled: listRect.enabled && !!list.current && list.current.canDel
                                    onClicked: list.current ? list.current.del() : null
                                }
                            }

                            SettingsCommon.SettingsToolbarToggleButton
                            {
                                id: showDisconnected

                                target: context
                                property: "showDisconnected"
                                objectName: "showDisconnected"

                                iconImage: "../../common/images/settings/firewall/disconnected" + (enabled ? "" : "_disabled") + ".png"

                                anchors.right: parent.right
                                anchors.rightMargin: 10
                                anchors.verticalCenter: parent.verticalCenter

                                text: tr.Localize("DisconnectedFilter")
                                enabled: listRect.enabled
                            }

                            Widgets.DPIScaler {changeHeight: true}
                        }

                        Rectangle
                        {
                            width: parent.width
                            height: 1
                            color: "lightgray"
                        }


                        ListView
                        {
                            id: list
                            width: parent.width
                            model: context.zones
							height: listRect.height - y
							clip: true
                            property Item current
                            onModelChanged: list.current = null
							interactive: false

							Widgets.FlickableScrollBar
							{
								anchors.right: list.right
								anchors.top: list.top
								anchors.bottom: list.bottom
								target: list
							}

                            Rectangle
                            {
                                visible: !!list.current
                                color: listRect.getCurrentSelectColor()
                                x: list.current ? list.current.x : 0
								y: list.current ? list.current.y - list.contentY : 0
                                width: list.current ? list.current.width : 0
                                height: list.current ? list.current.height : 0
                                z: -1
                            }

                            PopupMenu
                            {
                                id: menu
                                width: childrenRect.width
                                property bool enabledNotUntrusted: !!list.current && !!list.current.severityEditable
                                items:
                                [
                                    PopupMenuAction { text: tr.Localize("NetSeverityUntrusted"); onTriggered: list.current.setSeverity(0)},
                                    PopupMenuAction { text: tr.Localize("NetSeverityLocal"); onTriggered: list.current.setSeverity(1); enabled: menu.enabledNotUntrusted },
                                    PopupMenuAction { text: tr.Localize("NetSeverityTrusted"); onTriggered: list.current.setSeverity(2); enabled: menu.enabledNotUntrusted }
                                ]
                            }

                            delegate: Item
                            {
                                id: zoneItem
                                width: parent.width
                                height: netImage.height + 4


                                property bool canEdit: true
                                property bool canDel: true
                                property bool severityEditable: modelData.severityEditable

                                function edit()
                                {
                                    context.EditZone(modelData.id);
                                }

                                function del()
                                {
                                    list.current = null
                                    context.DeleteZone(modelData.id);
                                }

                                function setSeverity(value)
                                {
                                    modelData.severity = value;
                                }


                                Image
                                {
                                    id: netImage
                                    anchors.left: parent.left
                                    anchors.leftMargin: 20
                                    anchors.verticalCenter: zoneItem.verticalCenter
                                    smooth: true

                                    source: "../../common/images/settings/firewall/" + EnumExtension.ConvertToEnumKey(context, "NetSeverity", modelData.severity) + (listRect.enabled ? "" : "_disabled") + ".png"
                                    Widgets.DPIScaler {changeSize: true}
                                }

                                SettingsCommon.SettingsStandardText
                                {
                                    id: netText

                                    anchors.left: netImage.right
                                    anchors.leftMargin: 3
                                    anchors.right: netInfo.left
                                    anchors.verticalCenter: zoneItem.verticalCenter
                                    horizontalAlignment: Text.AlignLeft
                                    color: listRect.getCurrentTextColor(parent)
                                    elide: Text.ElideRight
                                    text: modelData.name
                                }

                                SettingsCommon.SettingsStandardText
                                {
                                    id: netInfo

                                    anchors.right: parent.right
                                    anchors.rightMargin: 10
                                    anchors.verticalCenter: zoneItem.verticalCenter
                                    text: tr.Localize(EnumExtension.ConvertToEnumKey(context, "NetSeverity", modelData.severity))
                                    color: listRect.getCurrentTextColor(parent)
                                }

                                MouseArea
                                {
                                    anchors.fill: parent
                                    acceptedButtons: Qt.LeftButton | Qt.RightButton
                                    onDoubleClicked: edit();
                                    onClicked:
                                    {
                                        if (listRect.enabled) {
                                            scope.focus = true;
                                            list.current = zoneItem;
                                            if (mouse.button == Qt.RightButton)
                                                menu.Show(Qt.point(mouse.x, mouse.y));
                                        }
                                    }
                                }

                                Widgets.DPIScaler {changeHeight: true}
                            }
                            section.property: "adapterId";
                            section.delegate: Item
                            {
                                id: adapterItem

                                property bool canEdit: true
                                property bool canDel: false

                                width: parent.width
                                height: adapterImage.height + 4

                                function edit()
                                {
                                    context.EditAdapter(section);
                                }

                                Image
                                {
                                    id: adapterImage

                                    anchors.left: parent.left
                                    anchors.leftMargin: 3
                                    anchors.verticalCenter: adapterItem.verticalCenter
                                    smooth: true

                                    source: "../../common/images/settings/firewall/network" + (listRect.enabled ? "" : "_disabled") + ".png"
                                    Widgets.DPIScaler {changeSize: true}
                                }

                                SettingsCommon.SettingsStandardText
                                {
                                    id: adapterText

                                    property string adapterName: context.GetAdapterName(section)
                                    text: adapterName ? adapterName : tr.Localize("OtherNetworks")
                                    font: settingsPage.fontStyles.standardCommonTextFontBold
                                    color: listRect.getCurrentTextColor(parent)

                                    anchors.left: adapterImage.right
                                    anchors.leftMargin: 3
                                    anchors.verticalCenter: adapterItem.verticalCenter
                                }

                                MouseArea
                                {
                                    anchors.fill: parent
                                    onClicked:
                                    {
                                        if (listRect.enabled)
                                        {
                                            scope.focus = true;
                                            list.current = adapterItem;
                                        }
                                    }
                                    onDoubleClicked:
                                    {
                                        if (listRect.enabled)
                                            edit();
                                    }
                                }

                                Widgets.DPIScaler {changeHeight: true}
                            }
                        }
                    }
                }
            }
        }
    }
}
