import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper
import "../common/DateTime.js" as DateTime
import "../common/HelpMapper.js" as HelpMapper

ActivationBasePage
{
	Localizer { id:tr; scope:"LicenseManager" }
	headerString:			tr.Localize("ActivationHasLicense_Header")
	objectName: "activationHasLicense"

	function getHelpId()
	{
        return HelpMapper.ActivationPageHasLicenseHelpId;
	}

	Column
	{
		id: 			licenseInfo
		anchors.top:	parent.top
		anchors.left:	parent.left
		anchors.right:	parent.right
		spacing:		7

		Widgets.StaticLabel
		{
			objectName: "typeOfProgram"
			caption: tr.Localize("ActivationHasLicense_TypeOfProgram")
			value: context.ActivationPageHasLicense.LicenseFromOtherProduct_ProductName == "" ? "" : tr.Localize("ProductName_" + context.ActivationPageHasLicense.LicenseFromOtherProduct_ProductName);
			anchors.left:	parent.left
		}
		Widgets.StaticLabel
		{
			objectName: "typeOfLicense"
			caption: tr.Localize("ActivationHasLicense_TypeOfLicense")
			value: tr.Localize("ActivationManager_LicenseFromOtherProduct_LicenseTypeDescription", {
				"LicenseFromOtherProduct_LicenseType" : tr.Localize(context.ActivationPageHasLicense.LicenseFromOtherProduct_LicenseType),
				"LicenseFromOtherProduct_PcCount" : context.ActivationPageHasLicense.LicenseFromOtherProduct_PcCount
				})
			anchors.left:	parent.left
		}
		Widgets.StaticLabel
		{
			objectName: "dateOfExpirations"
			caption: tr.Localize("ActivationHasLicense_DateOfExpirations")
            value: tr.LocalizeDateTimeShort(context.ActivationPageHasLicense.LicenseFromOtherProduct_ExpirationDate);
			anchors.left:	parent.left
		}
	}
	Text
	{
		id: actionText
		objectName: "actionText"
		anchors.top: licenseInfo.bottom
		anchors.topMargin: 30
		anchors.left:	parent.left
		anchors.right:	parent.right
		horizontalAlignment: Text.AlignLeft

		text: tr.Localize("ActivationHasLicense_ActionText")
		font: activationWizard.standartFontStyles.standardSectionCaptionFont
	}
	Column
	{
		id: selectionBlock
		objectName: "selectionBlock"
		anchors.top: actionText.bottom
		anchors.topMargin: 18
		anchors.left:	parent.left
		anchors.right:	parent.right
		spacing:		12

		Widgets.RadioGroup		{id: selectionForUsingCurrentLicense}

		Widgets.RadioButton
		{
			id:					selectionForChangeProductType
			objectName: "selectionForChangeProductType"
			anchors.left:		parent.left
			anchors.right:		parent.right
			color: 				"transparent"
			horizontalMargin:	7
			text:				tr.Localize("ActivationHasLicense_ReturnToPrevProduct", {
                "LicenseFromOtherProductProductName" : context.ActivationPageHasLicense.LicenseFromOtherProduct_ProductName == "" ?
                    "" :
                    tr.Localize("ProductName_" + context.ActivationPageHasLicense.LicenseFromOtherProduct_ProductName)
                });
			checked:			true
			group:				selectionForUsingCurrentLicense
			textVerticalMargin: 1
			
			onCheckedChanged:
			{
				if (checked)
					context.UserChoice = "UserChoice_Migrate";
			}			
		}

		Widgets.RadioButton
		{
			id:					selectionForActivateWithNewCode
			objectName: "selectionForActivateWithNewCode"
			anchors.left:		parent.left
			anchors.right:		parent.right
			color: 				"transparent"
			horizontalMargin:	7
			text:				tr.Localize("ActivationHasLicense_UseNewLicenseText")
			group:				selectionForUsingCurrentLicense
			textVerticalMargin: 1
			onCheckedChanged:
			{
				if (checked)
					context.UserChoice = "UserChoice_ActivateWithNewCode";
			}				
		}
	}
}

