import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/widgets" as Widgets
import "../common/HelpMapper.js" as HelpMapper

ActivationBasePage
{
	Localizer { id:tr; scope:"LicenseManager" }
	headerString:		tr.Localize("KeyForOtherProductPageHeader")
	objectName: "keyForOtherProductPageHeader"

	onVisibleChanged:
	{
		if (visible)
			context.UserChoice = "UserChoice_ActivateFromOtherProduct";
	}

	function getHelpId()
	{
		return ProductTypeHelper.isKIS() ? HelpMapper.ActivationPageOtherProductHelpIdKIS : HelpMapper.ActivationPageOtherProductHelpIdKAV;
	}

	Column
	{
		id: infoBlock
		spacing: 5

		anchors.left: parent.left
		anchors.right: parent.right

		Widgets.StaticLabel
		{
			objectName: "keyForOtherProductPageInfoBlockActivationCode"
			caption:		tr.Localize("KeyForOtherProductPageInfoBlockActivationCode")
			value:			context.ActivationCode
			captionFont:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
			valueFont:		activationWizard.fontStyles.masterOfActivationButtonsNormalText
		}
		Widgets.StaticLabel
		{
			objectName: "keyForOtherProductPageInfoBlockProductName"
			caption:		tr.Localize("KeyForOtherProductPageInfoBlockProductName")
			value:			context.ProductName
			captionFont:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
			valueFont:		activationWizard.fontStyles.masterOfActivationButtonsNormalText
		}
	}
	Widgets.RadioGroup {id: radioGroupSelectionForChangeProductType}
	Widgets.RadioButton
	{
		id:						selectionForChangeProductType
		objectName: "selectionForChangeProductType"
		text:					tr.Localize("SelectionTextForChangeProductType")
		color: 					"transparent"
		group:					radioGroupSelectionForChangeProductType
		horizontalMargin:		7
		textfont:				activationWizard.fontStyles.checkBoxTextNormal
		checked:				true
		anchors.top:			infoBlock.bottom
		anchors.topMargin:		30
		textVerticalMargin: -1
		visible:				context.ActivationPageOtherProductDueReserve.NotTrialActiveLicense
		
		onCheckedChanged:
		{
			if (checked)
				context.UserChoice = "UserChoice_ActivateFromOtherProduct";
		}
	}

	Text
	{
		id: 				activationCodeIntendedForProductDescription
		objectName: "activationCodeIntendedForProductDescription"
		font:				activationWizard.fontStyles.masterOfActivationButtonsNormalText
		anchors.top:		selectionForChangeProductType.bottom
		anchors.topMargin:	12
		anchors.left:		parent.left
		anchors.leftMargin:	24
		anchors.right:		parent.right
		wrapMode:			Text.Wrap
		text:				tr.Localize("ActivationCodeIntendedForProductDescription")
	}

	Widgets.RadioButton
	{
		id:						selectionForChangeProductTypeLater
		objectName: "selectionForChangeProductTypeLater"
		text:					tr.Localize("SelectionTextForChangeProductTypeLater")
		color: 					"transparent"
		group:					radioGroupSelectionForChangeProductType
		horizontalMargin:		7
		textfont:				activationWizard.fontStyles.checkBoxTextNormal
		anchors.top:			activationCodeIntendedForProductDescription.bottom
		anchors.topMargin:		30
		checked:				!selectionForChangeProductType.checked
		textVerticalMargin: -1
		visible:				context.ActivationPageOtherProductDueReserve.NotTrialActiveLicense
		
		onCheckedChanged:
		{
			if (checked)
				context.UserChoice = "UserChoice_Reserve";
		}
	}

	Text
	{
		id: 				activationCodeIntendedForProductLaterDescription
		objectName: "activationCodeIntendedForProductLaterDescription"
		font:				activationWizard.fontStyles.masterOfActivationButtonsNormalText
		anchors.top:		selectionForChangeProductTypeLater.bottom
		anchors.topMargin:	12
		anchors.left:		parent.left
		anchors.leftMargin:	24
		anchors.right:		parent.right
		wrapMode:			Text.Wrap
		text:				tr.Localize("ActivationCodeIntendedForProductLaterDescription")
		visible:			context.ActivationPageOtherProductDueReserve.NotTrialActiveLicense
	}
}

