import QtQuick 1.1
import "../fonts" as Fonts
import "../Common.js" as Common
import "../Stat.js" as Stat

Rectangle
{
	id: checkbox

    signal toggled(bool result)

	// public default target property
	property bool checked: false
	// public settable:
	property variant target: checkbox
	property string property: "checked"
    property bool inverted: false
    property bool canToggle: true
    property real textMargin: checkImage.width + horizontalMargin

    // private:
	property int tabOrder: 1
	property bool setFocusOnPressed: tabOrder ? true : false

	property variant fontStyles: Fonts.Common{}

	property string text: ""
	property alias textfont: buttonText.font
	property alias wrapMode: buttonText.wrapMode
	property alias elide: buttonText.elide
	property variant textcolor: "Black"
	property variant textcolorDisabled: "Gray"

    property int horizontalMargin: 6
	property int verticalMargin: 1
	property real textVerticalMargin: 0

	property int maxWidth: parent.width
	property int maxHeight: 2000
    property string uncheckedImage: "../images/widgets/checkbox.png"
    property string uncheckedHoverImage
    property string uncheckedPressedImage
    property string checkedImage: "../images/widgets/checkbox_selected.png"
    property string checkedHoverImage
    property string checkedPressedImage
    property string uncheckedDisabledImage: "../images/widgets/checkbox_disabled.png"
    property string checkedDisabledImage: "../images/widgets/checkbox_selected_disabled.png"

	// private
	property real baseWidth: checkImage.width + 3 * horizontalMargin
    property real textWidth: buttonTextWithoutElide.paintedWidth

	function getImage()
	{
        if (enabled)
        {
            if (uncheckedHoverImage && state == "pressed")
                return target[property] != inverted ? checkedPressedImage : uncheckedPressedImage;
            if (uncheckedPressedImage && (state == "pressed" || state == "hover"))
                return target[property] != inverted ? checkedHoverImage : uncheckedHoverImage;
            return target[property] != inverted ? checkedImage : uncheckedImage;
        }
        else
        {
            return target[property] != inverted ? checkedDisabledImage : uncheckedDisabledImage;
        }
	}

    function selectValue(disabled, normal, hover, pressed)
    {
        if (!enabled)
            return disabled ? disabled: normal;
        if (state == "pressed" && pressed)
            return pressed;
        if ((state == "pressed" || state == "hover") && hover)
            return hover;
        return normal;
    }

	width: Math.min(maxWidth, baseWidth + textWidth)
	height: Math.min(widgetArea.height, maxHeight)
	color: "transparent";

	HotKeyParser
	{
		id: hotKeyParser
		text: checkbox.text
	}
	HotKey
	{
		text: hotKeyParser.hotKeyText
		onPressed: toggle();
	}

	function toggle()
	{
        if(canToggle)
        {
            target[property] = !target[property];
            if (!checkbox.activeFocus && checkbox.setFocusOnPressed)
                checkbox.forceActiveFocus();
        }
        Stat.onButtonClick(Common.buildDelegatelessPath(checkbox));
        toggled(canToggle)
	}

	Keys.onSpacePressed: toggle()

	Item
	{
		id: widgetArea
		height: childrenRect.height
        anchors.verticalCenter: parent.verticalCenter
		width: parent.width
		Item
		{
			id: topMargin;
			height: checkbox.verticalMargin
			width: parent.width
		}
		Item
		{
			id: visualElements
			anchors.top: topMargin.bottom
			height: Math.max(checkImage.height, buttonText.height)
			width: parent.width

			Image
			{
				id: checkImage
				anchors.left: parent.left
				anchors.leftMargin:	1
				height: sourceSize.height
				width: sourceSize.width
				fillMode: Image.Stretch
				smooth: true
				source: checkbox.getImage();
				anchors.top: parent.top
				DPIScaler
				{
					id: dpiScaler
					changeSize: true
				}
			}

			Text
			{
				id: buttonText
				text: hotKeyParser.textToShow
				font: checkbox.fontStyles.standardCheckboxFont
				elide: (!wrapMode || (wrapMode == Text.NoWrap)) ? Text.ElideRight : Text.ElideNone
                wrapMode: Text.WordWrap
				verticalAlignment: Text.AlignVCenter
				color: checkbox.enabled ? textcolor : textcolorDisabled
				anchors.left: checkImage.right
				anchors.leftMargin: checkbox.horizontalMargin
				anchors.right: parent.right
				anchors.rightMargin: checkbox.horizontalMargin
				anchors.top: parent.top
                anchors.topMargin: checkbox.textVerticalMargin
			}

			Text
			{
				id: buttonTextWithoutElide
				x: buttonText.x
				y: buttonText.y
				visible: false
				font: buttonText.font
				text: buttonText.text
			}

            FocusImage
            {
                target: checkbox
                anchors.left: parent.left
                anchors.leftMargin: -5
                anchors.verticalCenter: parent.verticalCenter
                widthClipperSize: 4
                heightClipperSize: -10
                tileHorizontally: true
                tileVertically: true
                border {
                    top: 8
                    bottom: 10
                    left: 4
                    right: 4
                }
                source: "../images/focuses/focus_gray_rect.png"
            }
		}
	}


	MouseArea
	{
		id: mouseArea
		anchors.fill: parent
		hoverEnabled: true
		Clickable {}
		onClicked: toggle()
	}

    states
    {
        State
        {
            name: "normal"
            when: !mouseArea.containsMouse
        }
        State
        {
            name: "hover"
            when: mouseArea.containsMouse && mouseArea.pressedButtons != Qt.LeftButton
        }
        State
        {
            name: "pressed";
            when: mouseArea.containsMouse && mouseArea.pressedButtons == Qt.LeftButton;
        }
    }
}
