import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper

Widgets.Wizard
{
	id:migrationWizard
	objectName: "migrationWizard"
	Localizer { id:tr; scope:"MigrationWizard" }
	localizer : tr.scope != "" ? tr : undefined;
    function init() {}
    context: MainWindow.migrationWizard
    property variant currentPage: context.CurrentPage
    property string page: ""

    windowDescriptionText: tr.Localize("MigrationMasterWizardCaption")
    	
    onCurrentPageChanged:
    {
		selectPageOnStateChanged(false);
		page = EnumHelper.getKey(context, "CurrentPage")
    }

    MigrationInfoPage { id: infoPage; parentWizard: migrationWizard; }
    MigrationSearchPage { id: searchPage; parentWizard: migrationWizard;}
    MigrationAppListPage { id: appListPage; parentWizard: migrationWizard;}
    MigrationProcessPage { id: processPage; parentWizard: migrationWizard;}
    MigrationRebootPage { id: rebootPage; parentWizard: migrationWizard;}

    Component.onCompleted:
    {
        infoPage.parent = getWorkingArea();
        searchPage.parent = getWorkingArea();
        appListPage.parent = getWorkingArea();
        processPage.parent = getWorkingArea();
        rebootPage.parent = getWorkingArea();
        selectPageOnStateChanged(false);
    }

    function selectPageOnStateChanged(saveCurrentPage)
    {
        var page = infoPage;
        switch (EnumHelper.getKey(context, "CurrentPage"))
        {
        case "WizardBegin":
        case "WizardContinue":
        case "RestartProduct":
        case "MigrationAborted":
            page = infoPage;
            break;
        case "SearchSafeRemovalApplications":
        case "SearchManualRemovalApplications":
        case "SearchUnsafeRemovalApplications":
        case "UnsafeRemovalProgress":
        case "SafeRemovalProgress":
        case "MigrationProgress":
            page = processPage;
            break;
        case "SafeRemovalApplications":
        case "ManualRemovalApplications":
        case "UnsafeRemovalApplications":
            page = appListPage;
            break;
        case "RebootOs":
            page = rebootPage;
            break;

        case "WizardFinish": // TODO: remove from VM
        default:
                console.log("Can't select page for: MigrationState = '" + EnumHelper.getKey(context, "CurrentPage") + "'");
        }

        setNewPage(page, saveCurrentPage);
    }
    
    Widgets.GrayButton
    {
		anchors.bottom:			parent.footerAnchors.bottom
		anchors.bottomMargin:	parent.footerAnchors.bottomMargin
		anchors.left: parent.left
		anchors.leftMargin: workAreaLeftGap
        objectName: "skipButton"
                
        text: tr.Localize("SkipButton");
        onClicked:
        {
			context.SkipAction.Invoke()
        }

        visible:	page == "SafeRemovalApplications" || 
					page == "ManualRemovalApplications" || 
					page == "UnsafeRemovalApplications"
    }
}
