import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/border" as Border
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/Margins.js" as Margins
import "../common/EnumHelper.js" as EnumHelper
import "../common/HelpMapper.js" as HelpMapper

Border.BorderedContent
{
    content: secureKeyboardUrlSettingsDialog

    property variant context: UrlMasksViewModel
    property variant commonFontStyles: Fonts.Common{}

    Widgets.SecondaryWindow
    {
        id: secureKeyboardUrlSettingsDialog

        property int helpId: HelpMapper.SecureKeyboardCategoriesSettingsHelpId

        objectName: "SecureKeyboardUrlSettingsDialog"
        width: 500
        height: 550
        Localizer { id: tr; scope: "SecureKeyboardSettings" }
        caption: tr.Localize("SecureKeyboard");

        workArea: FocusScope
        {
            objectName: "WorkArea"
            anchors.fill: parent

            Rectangle
            {
                id: background
                anchors.fill: parent
                color: "#f3f3f3"
            }


            Widgets.TabPageStack
            {
                id: tabPageStack
                anchors.fill: parent
                anchors.topMargin: 7
                objectName: "SecureKeyboardTabPageStack"

                tabTextPointSize: commonFontStyles.standardCommonTextFont.pointSize
                tabTextFamily: commonFontStyles.standardCommonTextFont.family
                tabTextBold: commonFontStyles.standardCommonTextFont.bold

                onCurrentChanged:
                {
                    if (current === 0)
                        secureKeyboardUrlSettingsDialog.helpId = HelpMapper.SecureKeyboardCategoriesSettingsHelpId
                    else
                        secureKeyboardUrlSettingsDialog.helpId = HelpMapper.SecureKeyboardExclusionsSettingsHelpId
                }

                Widgets.Tab
                {
                    id: categoriesTab
                    title: tr.Localize("Categories")

                    Rectangle
                    {
                        id: categoriesBackground
                        anchors.fill: parent
                        color: "white"
                    }

                    Column
                    {
                        id: categoriesColumn
                        anchors.fill: parent
                        anchors.margins: 10

                        spacing: 10

                        Text
                        {
                            id: categoriesDescription

                            anchors.left: parent.left
                            anchors.right: parent.right

                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft
                            wrapMode: Text.WordWrap

                            text: tr.Localize("CategoriesDescription");
                        }

                        Column
                        {
                            id: supportFlags
                            anchors.left: parent.left
                            anchors.right: parent.right
                            spacing: 8

                            Widgets.CheckBox
                            {
                                id: passwordFieldsSupport
                                objectName: "PasswordFieldsSupport"
                                anchors.left: parent.left
                                text: tr.Localize("EnablePasswordProtection");
                                target: context
                                property: "passwordFieldsSupport"
                            }

                            Widgets.CheckBox
                            {
                                id: safeBankingSupport
                                objectName: "SafeBankingSupport"
                                anchors.left: parent.left
                                text: tr.Localize("EnableForSafeBanking");
                                target: context
                                property: "safeBankingSupport"
                            }
                        }

                        Text
                        {
                            id: categoriesSection

                            anchors.left: parent.left
                            anchors.right: parent.right

                            font: commonFontStyles.standardCommonTextFontBold
                            horizontalAlignment: Text.AlignLeft
                            wrapMode: Text.WordWrap
                            text: tr.Localize("CategoriesSection");
                        }

                        Column
                        {
                            id: categoriesFlags
                            anchors.left: parent.left
                            anchors.right: parent.right
                            spacing: 8

                            Widgets.CheckBox
                            {
                                id: protectCategoryBanksCheckBox
                                objectName: "ProtectedCategoryBanksCheckBox"
                                anchors.left: parent.left
                                text: tr.Localize("Banks");
                                target: context
                                property: "protectCategoryBanks"
                            }
                            Widgets.CheckBox
                            {
                                id: protectCategoryPaymentSystemsCheckBox
                                objectName: "ProtectCategoryPaymentSystemsCheckBox"
                                anchors.left: parent.left
                                text: tr.Localize("PaymentSystems");
                                target: context
                                property: "protectCategoryPaymentSystems"
                            }
                            Widgets.CheckBox
                            {
                                id: protectCategoryWebMailCheckBox
                                objectName: "ProtectCategoryWebMailCheckBox"
                                anchors.left: parent.left
                                text: tr.Localize("MailSystems");
                                target: context
                                property: "protectCategoryWebMail"
                            }
                            Widgets.CheckBox
                            {
                                id: protectCategoryChatForumCheckBox
                                objectName: "ProtectCategoryChatForumCheckBox"
                                anchors.left: parent.left
                                text: tr.Localize("ConversationSites");
                                target: context
                                property: "protectCategoryChatForum"
                            }
                            Widgets.CheckBox
                            {
                                id: protectCategorySocialNetsCheckBox
                                objectName: "ProtectCategorySocialNetsCheckBox"
                                anchors.left: parent.left
                                text: tr.Localize("SocialSystems");
                                target: context
                                property: "protectCategorySocialNets"
                            }
                        }
                    }
                }

                Widgets.Tab
                {
                    id: exceptionTab
                    title: tr.Localize("Exceptions")

                    Rectangle
                    {
                        id: exceptionBackground
                        anchors.fill: parent
                        color: "white"
                    }


                    Column
                    {
                        id: secureKeyboardColumn

                        anchors.fill:parent
                        anchors.margins: 10

                        spacing: 10

                        Text
                        {
                            id: urlMaskSettingsDescription

                            anchors.left: parent.left
                            anchors.right: parent.right

                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft
                            wrapMode: Text.WordWrap

                            text: tr.Localize("UrlSettingsDescription");
                        }

                        Text
                        {
                            id: showIconDescription

                            anchors.left: parent.left
                            anchors.right: parent.right

                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft

                            text: tr.Localize("ShowIconDescription");
                        }

                        Widgets.EditableListView
                        {
                            model: context.inclusiveUserUrlMasks

                            addText: tr.Localize("AddInclusive")
                            editText: tr.Localize("EditInclusive")
                            deleteText: tr.Localize("DeleteInclusive")

                            addImage: "../images/protected_input/add.png"
                            editImage: "../images/protected_input/edit.png"
                            deleteImage: "../images/protected_input/delete.png"
                            addDisabledImage: "../images/protected_input/add.png"
                            editDisabledImage: "../images/protected_input/edit_disabled.png"
                            deleteDisabledImage: "../images/protected_input/delete_disabled.png"


                            anchors.left: parent.left
                            anchors.right: parent.right
                            height: 150

                            textPropertyName: "urlMask"

                            onAddElement:
                            {
                                context.AddInclusiveMask();
                            }

                            onEditElement:
                            {
                                context.EditInclusiveMask(index)
                            }

                            onDeleteElement:
                            {
                                context.DeleteInclusiveMask(index)
                            }
                        }

                        Text
                        {
                            id: dontshowIconDescription

                            anchors.left: parent.left
                            anchors.right: parent.right

                            font: commonFontStyles.standardCommonTextFont
                            horizontalAlignment: Text.AlignLeft

                            text: tr.Localize("DontShowIconDescription");
                        }

                        Widgets.EditableListView
                        {
                            model: context.exclusiveUserUrlMasks

                            addText: tr.Localize("AddExclusive")
                            editText: tr.Localize("EditExclusive")
                            deleteText: tr.Localize("DeleteExclusive")

                            addImage: "../images/protected_input/add.png"
                            editImage: "../images/protected_input/edit.png"
                            deleteImage: "../images/protected_input/delete.png"
                            addDisabledImage: "../images/protected_input/add.png"
                            editDisabledImage: "../images/protected_input/edit_disabled.png"
                            deleteDisabledImage: "../images/protected_input/delete_disabled.png"

                            textPropertyName: "urlMask"

                            anchors.left: parent.left
                            anchors.right: parent.right
                            height: 150

                            onAddElement:
                            {
                                context.AddExclusiveMask();
                            }

                            onEditElement:
                            {
                                context.EditExclusiveMask(index)
                            }

                            onDeleteElement:
                            {
                                context.DeleteExclusiveMask(index)
                            }
                        }

                        Widgets.DPIScaler {changeHeight: true}
                    }
                }
            }
        }

        buttonsArea: FocusScope
        {
            id: bottomRow
            anchors.fill: parent
            objectName: "bottom"
            property int tabOrder: 2


            Widgets.HelpButton
            {
                anchors
                {
                    verticalCenter: parent.verticalCenter
                    left: parent.left
                    leftMargin: 12
                }

                objectName: "help"
                text: tr.Localize("Help")
                onClicked: Help.Show(secureKeyboardUrlSettingsDialog.helpId)
            }

            Widgets.GrayButton
            {
                id: okButton

                minWidth: cancelButton.width
                //enabled: context.urlCorrect

                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: cancelButton.left
                    rightMargin: Margins.horizontalBetweenButtons
                }

                objectName: "OkButton"
                text: tr.Localize("ConfirmButton")
                onClicked:
                {
                    context.dialogResult = 0;
                    Window.Close();
                }
            }

            Widgets.GrayButton
            {
                id: cancelButton

                anchors
                {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                }

                objectName: "CancelButton"
                text: tr.Localize("CancelButton")
                onClicked:
                {
                    context.dialogResult = 1;
                    Window.Close()
                }
            }
        }

        Widgets.DPIScaler {
            id: dpiScaler
            changeHeight: true
        }
    }
}
