import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "GamingProfileSettingsPage"

    property int helpId: HelpMapper.GamingProfileSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "GamingProfile")
    property variant fontStyles: Fonts.Common{}

    Localizer { id: tr; scope: "GamingProfileSettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "FileMonitorGeneralSection"
            body: Column
            {
                objectName: "FileMonitorGeneral"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description_" + ProductTypeHelper.productTypeToString(context))
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    id: useGamingProfile
                    objectName: "UseGamingProfile"
                    anchors.left: parent.left

                    text: tr.Localize("UseGamingProfile");
                    isBold: true
                    target: context
                    property: "useGamingProfile"
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ProfileOptionsSection"
            name: tr.Localize("ProfileOptions")
            body: Column
            {
                objectName: "ProfileOptions"
                enabled: context.useGamingProfile
                spacing: Margins.settingsCheckboxSpacing

                SettingsCommon.CheckBox
                {
                    anchors.left: parent.left
                    objectName: "SuppressInteractive"

                    text: tr.Localize("SuppressInteractive");
                    target: context
                    property: "suppressInteractive"
                }

                SettingsCommon.CheckBox
                {
                    anchors.left: parent.left
                    objectName: "SuppressUpdates"

                    text: tr.Localize("SuppressUpdates");
                    target: context
                    property: "suppressUpdates"
                }

                SettingsCommon.CheckBox
                {
                    objectName: "SuppressScheduleScan"
                    anchors.left: parent.left

                    text: tr.Localize("SuppressScheduleScan");
                    target: context
                    property: "suppressScheduleScan"
                }

                SettingsCommon.CheckBox
                {
                    objectName: "SuppressManualScan"
                    anchors.left: parent.left

                    text: tr.Localize("SuppressManualScan");
                    target: context
                    property: "suppressManualScan"
                }
            }
        }
    }
}
