import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "NetworkPage"

    property int helpId: HelpMapper.NetworkSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "Network")
    property variant fontStyles: Fonts.Common{}
    Localizer { id: tr; scope: "NetworkSettings" }

    Column
    {
        objectName: "MainWrapper"

        width: parent.width

        SettingsCommon.SettingsSection
        {
            objectName: "ControlPortsSection"
            name: tr.Localize("ControlPorts")
            smallTopMargin: true

            body: Row
            {
                objectName: "ControlPorts"

				SettingsCommon.BoolRadioGroup
				{
					id: controlAllPorts
					property int tabOrder:1
					trueDescription: tr.Localize("ControlAllPorts")
					falseDescription: tr.Localize("ControlSelectedPorts")
					trueFirst: true
					target: context
					property: "controlAllPorts"
				}

				SettingsCommon.SettingsButton
				{
					anchors.top: parent.top
					anchors.topMargin: Margins.settingsRadioSpacing * 2
					objectName: "Select"
					text: tr.Localize("Select")
					enabled: !context.controlAllPorts
					onClicked: context.selectPorts()
				}
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ProtectedConnections"
            name: tr.Localize("ProtectedConnections")
            body: Column
            {
                objectName: "ProtectedConnectionsColumn"
				spacing: Margins.settingsBeforeButtonSpacingCompact
				
				SettingsCommon.CheckBox
				{
					objectName: "DecodeSSL"
					anchors.left: parent.left
					text: tr.Localize("DecodeSSL")
					target: context
					property: "decodeSsl"
				}

				SettingsCommon.EnumRadioGroup
				{
					id: checkProtectedConnections
					objectName: "CheckProtectedConnections"
					anchors.left: parent.left
					anchors.leftMargin: 21
					width: parent.width - 21
					
					enabled: context.decodeSsl

					target: context
					property: "decodeSslOptions"
					localizer: tr

					visible: context.parentalControlEnabled
				}
				
				Column
				{
					objectName: "DecodeSPDYColum"
					width: parent.width
					spacing: Margins.settingsAfterTextSpacing
					
					SettingsCommon.CheckBox
					{
						objectName: "DecodeSPDY"
						id: decodeSPDY
						anchors.left: parent.left
						anchors.leftMargin: 21
						anchors.right: parent.right
						text: tr.Localize("DecodeSPDY")
						target: context
						property: "decodeSPDY"
						enabled: context.decodeSsl
					}					

					SettingsCommon.SettingsStandardText
					{
						anchors.left: decodeSPDY.left
						anchors.leftMargin: 21
						anchors.right: parent.right
						text: tr.Localize("DecodeSPDYDescription")
						wrapMode: Text.Wrap
					}
				}
				
				SettingsCommon.SettingsButton
				{
					anchors.left: parent.left
					anchors.leftMargin: 21
					objectName: "InstallCertificate"
					text: tr.Localize("InstallCertificate")
					enabled: context.decodeSsl
					onClicked: context.installCertificate()
				}					

				SettingsCommon.SettingsStandardText
				{
					anchors.left: parent.left
					width: parent.width
					text: tr.Localize("CheckProtectedConnectionsDescription")
					wrapMode: Text.Wrap
				}				
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "ProxyServer"
            width: parent.width
            name: tr.Localize("ProxyServer")
			smallTopMargin: true
            smallBottomMargin: true

            body: Column
            {
                objectName: "ProxyServersColumn"
                width: parent.width
                spacing: Margins.settingsBeforeButtonSpacingCompact

                SettingsCommon.SettingsStandardText
                {
                    text: tr.Localize("ProxyServerDescription")
                    anchors.left: parent.left
                    width: parent.width
                    wrapMode: Text.Wrap
                }

                SettingsCommon.SettingsButton
                {
                    objectName: "ProxyServerSettings"
                    anchors.left: parent.left
                    text: tr.Localize("ProxyServerSettings")
                    onClicked: context.proxySettings()
                }
            }
        }
    }
}
