import QtQuick 1.1
import QtWidgetProxies 1.0
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../../common/HelpMapper.js" as HelpMapper
import "../../common/EnumHelper.js" as EnumHelper

Item
{
    id: settingsPage
    objectName: "ProtectedInputSettingsPage"

    property string helpUrl: "$HelpURLSettingsVirtualKeyboard"
    property int helpId: HelpMapper.VirtualKeyboardSettingsHelpId
    property bool isKis: ProductTypeHelper.productTypeToString(context) === "kis"

    property variant context: SettingsHelper.GetPageContext(Settings, "ProtectedInput")
    property variant fontStyles: Fonts.Common{}

    property bool needReboot: context.needReboot

    Localizer { id: tr; scope: "ProtectedInputSettings" }

    Column
    {
        objectName: "ProtectedInputColumn"

        width: parent.width
        spacing: Margins.settingsPageSpacing

        enabled: !needReboot

        SettingsCommon.SettingsSection
        {
            objectName: "DescriptionSection"
            body: Column
            {
                objectName: "DescriptionWrapper"
                spacing: Margins.settingsMainSectionSpacing
                width: parent.width

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                    horizontalAlignment: Text.AlignLeft
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "VirtualKeyboardSection"
            name: tr.Localize("VirtualKeyboardSectionName")

            body: Column
            {
                objectName: "VirtualKeyboardSectionColumn"
                spacing: Margins.settingsBeforeButtonSpacing
                width: parent.width

                Column
                {
                    objectName: "VirtualKeyboardCheckboxColumn"
                    spacing: Margins.settingsCheckboxSpacing
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: enableVirtualKeyboardShortcutActivationCheckBox
                        objectName: "VirtualKeyboardShortcutActivation"
                        anchors.left: parent.left
                        text: tr.Localize("EnableHotkey");
                        target: context
                        property: "enableVirtualKeyboardShortcutActivation"

                        canToggle: !needReboot

                        onToggled:
                        {
                            if (!result)
                                context.ShowRebootMessageBox();
                        }
                    }

                    SettingsCommon.CheckBox
                    {
                        id: enableVirtualKeyboard
                        objectName: "IsVirtualKeyboardEnabled"
                        anchors.left: parent.left
                        text: tr.Localize("IsVirtualKeyboardEnabled");
                        target: context
                        property: "enableVirtualKeyboard"

                        canToggle: !needReboot

                        onToggled:
                        {
                            if (!result)
                                context.ShowRebootMessageBox();
                        }
                    }
                }

                Widgets.GrayButton
                {
                    id: virtualKeyboardSettingsButton

                    anchors.left: parent.left

                    enabled: !needReboot

                    objectName: "VirtualKeyboardSettingsButton"
                    text: tr.Localize("SettingsKeyboard")
                    onClicked:
                    {
                        context.ShowVirtualKeyboardSettings();
                    }
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "SecureKeyboardSection"
            name: tr.Localize("SecureKeyboardSectionName")

            body: Column
            {
                objectName: "SecureKeyboardSectionColumn"
                spacing: Margins.settingsBeforeButtonSpacing

                SettingsCommon.CheckBox
                {
                    id: secureVirtualKeyboard
                    objectName: "IsSecureKeyboardEnabled"
                    anchors.left: parent.left
                    text: tr.Localize("IsSecureKeyboardEnabled");
                    target: context
                    property: "enableSecureKeyboard"

                    canToggle: !needReboot

                    onToggled:
                    {
                        if (!result)
                            context.ShowRebootMessageBox();
                    }
                }

                Widgets.GrayButton
                {
                    id: secureKeyboardSettingsButton

                    anchors.left: parent.left

                    enabled: !needReboot

                    objectName: "SecureKeyboardSettingsButton"
                    text: tr.Localize("Settings")
                    onClicked:
                    {
                        context.ShowSecureKeyboardSettings();
                    }
                }
            }
        }
    }

    Row
    {
        spacing: 7
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 5
        width: parent.width
        visible: needReboot

        Image
        {
            id: warning
            source: "../../common/images/ico_warning_16.png"
        }

        SettingsCommon.SettingsStandardText
        {
            text: tr.Localize(EnumHelper.getKey(Global, "productType") == "KasperskyInternetSecurity" ? "RebootNotificationKIS" : "RebootNotificationKAV");
            width: parent.width - warning.width - 7
            wrapMode: Text.Wrap
        }
    }
}
