import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/border" as Border

Border.BorderedContent
{
    content: settings
    function showPage(page)
    {
        settings.showPage(page)
    }
	Widgets.SecondaryWindow
	{
		id: settings
		objectName: "settings"
		width: 740
		height: 540
		Localizer { id: tr; scope: "Settings" }
		caption: tr.Localize("Caption");

		function showPage(page)
		{
			workAreaItem.showPage(page)
		}

		workArea: FocusScope
		{
			objectName: "WorkArea"
			property int tabOrder: 1
			property int helpId: settingsArea.helpId
			function showPage(page)
			{
				choiceArea.selectPage(page)
			}
			ChoiceArea
			{
				id: choiceArea
				height: parent.height
				anchors.left: parent.left
				model: Settings.groups
				property int tabOrder: 1
			}
			Rectangle
			{
				id: separateLine
				anchors
				{
					right: choiceArea.right
					top: parent.top
					bottom: parent.bottom
				}

				color: "#C8C8C8"
				height: parent.height
				width: 1
			}
			SettingsArea
			{
				id: settingsArea
				featureName: choiceArea.currentFeatureName
				height: parent.height
				anchors.left: separateLine.right
				anchors.right: parent.right
				property int tabOrder: 2
				context: Settings
			}
		}
		buttonsArea: FocusScope
		{
			id: bottomRow
			anchors.fill: parent
			objectName: "bottom"
			property int tabOrder: 2
			property int helpId
			Row
			{
				objectName: "links"
				property int tabOrder: 1
				anchors
				{
					verticalCenter: parent.verticalCenter
					left: parent.left
					leftMargin: 12
				}
				spacing: 12
				Widgets.HelpButton
				{
					objectName: "help"
					text: tr.Localize("Help")
					onClicked: Help.Show(bottomRow.helpId)
				}
				Widgets.HelpButton
				{
					objectName: "restore"
					text: tr.Localize("Restore")
					onClicked: Settings.RestoreSettings()
				}
			}
			function applyAndChangePageIfNeeded()
			{
				var invalidPage = Settings.Apply();
				if (invalidPage !== "")
				{
					settings.showPage(invalidPage)
					return false;
				}
				return !Settings.hasChanges;
			}
			Row
			{
				objectName: "buttons"
				property int tabOrder: 2
				anchors
				{
					verticalCenter: parent.verticalCenter
					right: parent.right
				}
				spacing: 5
				Widgets.GrayButton
				{
					setAsDefaultButton: true
					objectName: "confirm"
					minWidth: applyButton.width
					text: tr.Localize("ConfirmButton")
					onClicked:
					{
						if (!Settings.hasChanges || (Settings.hasChanges && applyAndChangePageIfNeeded()))
							Window.Close()
					}
				}
				Widgets.GrayButton
				{
					objectName: "cancel"
					minWidth: applyButton.width
                    text: tr.Localize("CancelButton")
					onClicked: Window.Close()
				}
				Widgets.GrayButton
				{
					id: applyButton
					objectName: "apply"
					minWidth:85
					text: tr.Localize("ApplyButton")
					enabled: Settings.hasChanges
					onClicked: applyAndChangePageIfNeeded()
				}
			}
		}
		Binding
		{
			target: settings.buttonsAreaItem
			property: "helpId"
			value: settings.workAreaItem.helpId
			when: !!settings.buttonsAreaItem && !!settings.workAreaItem
		}
		Widgets.DPIScaler {
			id: dpiScaler
			changeHeight: true
		}
	}
}
