import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
	id: settingsPage
	objectName: "WebMonitor"

    property string helpUrl: "$HelpURLSettingsWebMonitoring"
    property int helpId: HelpMapper.WebMonitorSettingsHelpId

	property variant context: SettingsHelper.GetPageContext(Settings, "WebMonitor")
    property variant fontStyles: Fonts.Common{}
	Localizer { id: tr; scope: "WebMonitorSettings" }

	Column
	{
		objectName: "Column"
		width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "WebMonitorGeneral"
            body: Column
            {
                objectName: "WebMonitorGeneralSection"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    anchors.left: parent.left
                    text: tr.Localize("Description")
                    wrapMode: Text.Wrap
                }

                SettingsCommon.CheckBox
                {
                    objectName: "UseWebMonitor"
                    textfont: settingsPage.fontStyles.standardSettingsBoldTextFont
                    text: tr.Localize("UseWebMonitor");
                    target: context
                    property: "enableWebMonitor"
                    anchors.left: parent.left
                }
            }
        }

		SettingsCommon.SecurityLevelSection
		{
			context: settingsPage.context.levelViewModel
			enabled: settingsPage.context.enableWebMonitor
		}

		SettingsCommon.SettingsSection
		{
			name: tr.Localize("ActionOnThreatDetection")
			enabled: settingsPage.context.enableWebMonitor
            body: SettingsCommon.EnumRadioGroup
			{
                objectName: "ActionOnThreatDetection"
			    function getLocalizerKey(enumName)
				{
					if (enumName=="ScanActionAuto")
						return context.interactionDisabled? "ScanActionAuto" : "ScanActionAsk";
					return enumName;
				}

				target: context
				property: "scanAction"
				localizer: tr
			}
		}

	}
}
