import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper
import "../common/DateTime.js" as DateTime

Column
{
	width: parent ? parent.width : 0
	spacing: 3
	objectName: "ksnInfo"

	Text
	{
		function getUserCountLocalizationKey(userCount)
		{
			if (userCount < 10) return "FileKsnStatistics_UserCountLess10";
			else if (userCount < 100) return "FileKsnStatistics_UserCountLess100";
			else if (userCount < 1000) return "FileKsnStatistics_UserCountLess1000";
			else if (userCount < 10000) return "FileKsnStatistics_UserCountMore1000";
			else if (userCount < 100000) return "FileKsnStatistics_UserCountMore10000";
			else if (userCount < 1000000) return "FileKsnStatistics_UserCountMore100000";
			return "FileKsnStatistics_UserCountMoreMillion";
		}

		function getKsnStatisticsMessageFirstLine(trustedFlag, userCount, localizer)
		{
			if (!trustedFlag)
				return localizer.Localize("FileKsnStatistics_Untrusted");
			return localizer.Localize(getUserCountLocalizationKey(userCount));
		}

		function getKsnStatisticsMessageSecondLine(userCount, firstRequestTime, localizer)
		{
			var dateTime = new Date();
			if(userCount != 0)
				dateTime = firstRequestTime;
			var postfix =
				DateTime.getApproximatePeriodPostfix(DateTime.helperConvertToTimeDuration(dateTime));
			return localizer.Localize("FileKsnStatistics_FirstRequestDate_" + postfix);
		}

		function composeKsnStatisticsMessage(trustedFlag, userCount, firstRequestTime, localizer)
		{
			var message = "<font color=\"black\">";
			message += localizer.Localize("TaskManager_CaptionStatistics");
			message += "</font> ";
			message += getKsnStatisticsMessageFirstLine(trustedFlag, userCount, localizer);
			message += ". ";
			message += getKsnStatisticsMessageSecondLine(userCount, firstRequestTime, localizer);
			return message;
		}

		anchors.left: parent.left
		width:		parent.width
		textFormat:	Text.StyledText
		color: 		"gray";
		text:		composeKsnStatisticsMessage(taskModel.KsnTrustedFlag, taskModel.KsnUserCount, taskModel.KsnFirstRequestTime, tr);
		font:		commonFontStyles.standardCommonTextFont
		wrapMode: 	Text.Wrap
		horizontalAlignment: Text.AlignLeft
	}
	Widgets.Hyperlink
	{
		objectName: "ksnDetails"
		focus: true
		setFocusOnPressed: true
		tabOrder: 0
		anchors.left: parent.left
		Localizer { id:tr; scope:"ScanTask" }
		text: tr.Localize("TaskManager_CaptionDetails")
		onClicked: taskModel.ShowFileAdvisorDialog();
	}
}
