import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame
import "../common/Colors.js" as Colors
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/DateTime.js" as DateTime
import "../common/HelpMapper.js" as HelpMapper

MainFrame.InnerContent
{
	Localizer { id:trMainWindow; scope:"MainWindow" }
	caption: trMainWindow.Localize("Updater")
	objectName: "updaterContent"
    property int helpId: HelpMapper.UpdaterHelpId
    property string settingsPage: "Updater"
	
	Localizer { id:tr; scope:"Update" }
	
	viewArea: Component
	{
		Item
		{
			property variant commonFontStyles: Fonts.Common{}

			anchors.fill: parent
			objectName: "updaterPanel"
	
			property int indent: 8
			property variant context: MainWindow.updater
			property variant updater: MainWindow.updater			

			Image
			{
				id: icon
				anchors.horizontalCenter: parent.left
                anchors.horizontalCenterOffset: descriptionArea.anchors.leftMargin / 2
				y: 40
				source: "../common/images/updater/ico_update_bases_48.png"
			}
		
			Item
			{
				id: descriptionArea
				objectName: "descriptionArea"
				anchors.left: parent.left
				anchors.leftMargin: 105
				anchors.right: parent.right
				anchors.top: icon.top
				anchors.topMargin: 5
				height: 100
			
				Widgets.StandardCaptionText
				{
					id: descriptionCaption
					text: tr.Localize(updater.UpdaterContext.text, {"Update_PercentCompleted" : context.PercentCompleted})

					anchors.left: parent.left
					anchors.right: parent.right

                    horizontalAlignment: Text.AlignLeft
					wrapMode: Text.WordWrap
					color:
					{
						switch(context.UpdaterContext.state)
						{
                            case "Info":		return Colors.green
                            case "Critical":	return Colors.red
                            case "Warning":		return Colors.yellow
							default: return "black"
						}
					}
				}
			
				Text
				{
					id: hintsArea
					anchors.top: descriptionCaption.bottom
                    anchors.topMargin: 6
					anchors.left: descriptionCaption.left
					anchors.right: descriptionArea.right
					anchors.rightMargin: 30
                    horizontalAlignment: Text.AlignLeft
					font: commonFontStyles.standardCommonTextFont
                    text: tr.Localize("BasesAndModulesDescription_" + ProductTypeHelper.productTypeToString(context))
                    lineHeight: 1.1                    
					wrapMode: "WordWrap"
				}
		
                Item
				{
					id: updaterArea
					objectName: "updaterArea"
					anchors.top: hintsArea.bottom
                    anchors.topMargin: 25
                    Widgets.DPIScaler { id: scaler }
                    height: 56 * scaler.factor
                    width: parent.width

                    Column
                    {
                        id: detailsView
                        objectName: "detailsView"
                        spacing: 3
                        height: parent.height
                        width: parent.width

                        property bool isIdleUpdateStatus: context.updateStatus === "Idle"
                        property bool isRollbackRunning: context.updateStatus === "RollbackRunning"

                        Row
                        {
                            id: detailsFirstRow
                            anchors.left: parent.left
                            spacing: 5

                            property string key: !detailsView.isIdleUpdateStatus ? tr.Localize("UpdateStatus") : tr.Localize("LastUpdate");
                            property string value: detailsView.isIdleUpdateStatus
                                                  ? DateTime.localizeTimeIntervalFromDateFullFormat(context.LastUpdateTime, tr)
                                                  : tr.Localize(context.updateStatus)
                            Text
                            {
                                text: detailsFirstRow.key;
                                font: commonFontStyles.standardCommonTextFont
                            }
                            Text
                            {
                                visible: !detailsView.isIdleUpdateStatus
                                text: detailsFirstRow.value;
                                font: commonFontStyles.standardCommonTextFont
                            }
                            Widgets.Hyperlink
                            {
                                objectName: detailsFirstRow.key + "Link"
                                visible: detailsView.isIdleUpdateStatus
                                text: detailsFirstRow.value;
                                onClicked: context.ShowUpdaterReportAction.Invoke()
                            }
                        }

                        Row
                        {
                            id: detailsSecondRow
                            visible: detailsView.isIdleUpdateStatus || !detailsView.isRollbackRunning
                            anchors.left: parent.left
                            spacing: 5

                            property string key: !detailsView.isIdleUpdateStatus ? tr.Localize("DownloadStatus") : tr.Localize("BasesSignatures");
                            property string value: detailsView.isIdleUpdateStatus
                                     ? tr.LocalizeNumber(context.SignatureCount)
                                     : tr.Localize(context.downloadStatus,
                                                   {"Updater_DownloadedSize" : context.DownloadedSize,
                                                    "Updater_DownloadedSpeed" : context.DownloadedSpeed
                                                   })
                            Text
                            {
                                text: detailsSecondRow.key;
                                font: commonFontStyles.standardCommonTextFont
                            }
                            Text
                            {
                                text: detailsSecondRow.value;
                                font: commonFontStyles.standardCommonTextFont
                            }
                        }

                        Row
                        {
                            id: detailsThirdRow
                            visible: detailsView.isIdleUpdateStatus || !detailsView.isRollbackRunning
                            anchors.left: parent.left
                            spacing: 5

                            property variant key: !detailsView.isIdleUpdateStatus ? tr.Localize("UpdateSource") : tr.Localize("BasesRunmode");

                            Text
                            {
                                text: detailsThirdRow.key
                                font: commonFontStyles.standardCommonTextFont
                            }
                            Text
                            {
                                visible: !detailsView.isIdleUpdateStatus
                                text: context.updateSource
                                font: commonFontStyles.standardCommonTextFont
                            }
                            Widgets.Hyperlink
                            {
                                objectName: detailsThirdRow.key + "Link"
                                visible: detailsView.isIdleUpdateStatus
                                text: tr.Localize(context.basesRunmode)
                                onClicked: context.SetUpdaterScheduleSettingsAction.Invoke()
                            }
                        }
                    }
                }
			
				Widgets.ComboButton
				{
					minWidth: 120
                    anchors.left: parent.left
					objectName: "updaterLauncher"
					actionList: updater.ActionData
                    anchors.top: updaterArea.bottom;
                    anchors.topMargin: 15
                    localizer:tr
                    visible: updater.ActionData.length != 0
					onPressed:
					{
						if(index < updater.ActionData.length)
						{
							var tempElement = updater.ActionData[index];
							if(tempElement.action != undefined)
								tempElement.action.Invoke()
						}
					}
				}
			}
			
			Widgets.Hyperlink
			{
				objectName: "visitVirusList"
				anchors.right: parent.right
				anchors.rightMargin: 20
				anchors.bottom: parent.bottom
				anchors.bottomMargin: 20
				text: tr.Localize("VirusListLinkText")
				onClicked: Window.OpenURL(updater.virusListLink);
			}
		}
	}
}


